==> ffb-init-1.0.2.tgz: package/index.js <==
#!/usr/bin/env node

const spawn = require("child_process").spawn;

const getGitCloneCmd = path =>
  `git clone git@gitlab.com:funkismultimedia/funkisdev/funkis-foundation-base.git ${path} --depth=1`;

const getNpmInstallCmd = path => `cd ${path} && npm install`;

const getNpmSetupCmd = path => `cd ${path} && npm run initialize-project`;

function runBashCommand(cmd) {
  console.log(`
  Running cmd ${cmd}
  `);
  return new Promise((resolve, reject) => {
    const SUCCESS_END_CODE = 0;

    // this way with "stdio" ensures the user can see the output from the commands we run https://stackoverflow.com/a/43477289/4763083
    const cmdProcess = spawn("/bin/sh", ["-c", cmd], { stdio: "inherit" });

    cmdProcess.on("exit", function(code) {
      endCode = code;
      if (endCode !== SUCCESS_END_CODE) {
        console.log("Something went wrong.. Could not upload files");
        reject();
      } else {
        console.log(`\nDone running cmd "${cmd}"`);
        resolve();
      }
    });
  });
}

const readline = require("readline").createInterface({
  input: process.stdin,
  output: process.stdout,
});

function getProjectPath() {
  let projectPath = process.argv[2];

  return new Promise((resolve, reject) => {
    if (!projectPath) {
      readline.question("\n\nChoose a path to create project in (default is the current directory): ", path => {
        resolve(path);
        readline.close();
      });
    } else {
      resolve(projectPath);
    }
  });
}

function createProjectFromPath(projectPath) {
  runBashCommand(getGitCloneCmd(projectPath))
    .then(() => runBashCommand(getNpmInstallCmd(projectPath)))
    .then(() => runBashCommand(getNpmSetupCmd(projectPath)));
}

(function init() {
  getProjectPath().then(path => {
    createProjectFromPath(path);
  });
})();

==> ffb-init-1.0.3.tgz: package/index.js <==
#!/usr/bin/env node

const spawn = require("child_process").spawn;

const getGitCloneCmd = path =>
  `git clone git@gitlab.com:funkismultimedia/funkisdev/funkis-foundation-base.git ${path} --depth=1`;

const getNpmInstallCmd = path => `cd ${path} && npm install`;

const getNpmSetupCmd = path => `cd ${path} && npm run initialize-project`;

const getEndMessageCmd = path =>
  `echo 'Done creating new project in ${path} !' && echo 'Go there and start the project with: ' && echo '${"cd " +
    path +
    " && npm run start"}'`;

const DEFAULT_RUN_BASH_OPTIONS = { logStart: true, logExit: true };
function runBashCommand(cmd, { logStart, logExit } = DEFAULT_RUN_BASH_OPTIONS) {
  logStart &&
    console.log(`
  Running cmd:  ${cmd}
  `);
  return new Promise((resolve, reject) => {
    const SUCCESS_END_CODE = 0;

    // this way with "stdio" ensures the user can see the output from the commands we run https://stackoverflow.com/a/43477289/4763083
    const cmdProcess = spawn("/bin/sh", ["-c", cmd], { stdio: "inherit" });

    cmdProcess.on("exit", function(code) {
      endCode = code;
      if (endCode !== SUCCESS_END_CODE) {
        console.log("Something went wrong.. Could not upload files");
        reject();
      } else {
        logExit && console.log(`\nDone running cmd:    ${cmd}`);
        resolve();
      }
    });
  });
}

const readline = require("readline").createInterface({
  input: process.stdin,
  output: process.stdout,
});

function getProjectPath() {
  let projectPath = process.argv[2];

  return new Promise((resolve, reject) => {
    if (!projectPath) {
      readline.question("\n\nChoose a path to create project in (default is the current directory): ", path => {
        resolve(path);
        readline.close();
      });
    } else {
      resolve(projectPath);
    }
  });
}

function createProjectFromPath(projectPath) {
  runBashCommand(getGitCloneCmd(projectPath))
    .then(() => runBashCommand(getNpmInstallCmd(projectPath)))
    .then(() => runBashCommand(getNpmSetupCmd(projectPath)))
    .then(() => runBashCommand(getEndMessageCmd(projectPath), { logStart: false, logExit: false }));
}

(function init() {
  getProjectPath().then(path => {
    createProjectFromPath(path);
  });
})();
